@@ -30,8 +30,8 @@ class TestTextPreprocessing(unittest.TestCase):
         cm.load_from_wb_database(db_name=config["wb_database"]["db_name"], db_user=config["wb_database"]["db_user"],
                                  db_password=config["wb_database"]["db_password"],
                                  db_host=config["wb_database"]["db_host"],
-                                 tazendra_ssh_user=tazendra_config["ssh"]["ssh_user"],
-                                 tazendra_ssh_passwd=tazendra_config["ssh"]["ssh_password"],
+                                 ssh_user=tazendra_config["ssh"]["ssh_user"],
+                                 ssh_passwd=tazendra_config["ssh"]["ssh_password"],
                                  paper_ids=['00059375'])
         fulltext = cm.get_paper('00059375').get_text_docs(remove_sections=[PaperSections.REFERENCES],
                                                           must_be_present=[PaperSections.METHOD, PaperSections.RESULTS])
